'use strict';

/**
 * 筛选栏-单选项组件
 */
var React = require('react');
var _ = require('lodash');
var classnames = require('classnames');

var _require = require('yylib-ui'),
    YYRow = _require.YYRow,
    YYCol = _require.YYCol,
    YYDatePicker = _require.YYDatePicker,
    YYInputNumber = _require.YYInputNumber,
    YYRangePicker = _require.YYRangePicker;

var CPFilterSingle = React.createClass({
    displayName: 'CPFilterSingle',

    getDefaultProps: function getDefaultProps() {
        return {
            rowKey: '', //行标识键值
            showAll: false, //是否显示全部
            minCount: 8, //最少显示个数
            defaultActivedKey: '', //默认激活项
            items: [], //{value: 1, text: '显示的文字'} value不可重复
            onClick: null, //点击单选时的回调函数
            colSpan: 3 //每个单位所占比例，24等份
        };
    },
    getInitialState: function getInitialState() {
        return {
            activeKey: this.props.defaultActivedKey,
            INValue: [] //inputNumber value
        };
    },
    componentWillReceiveProps: function componentWillReceiveProps(nextProps) {
        if ("defaultActivedKey" in nextProps && (nextProps.defaultActivedKey !== this.props.defaultActivedKey || nextProps.defaultActivedKey == '')) {
            this.setState({
                activeKey: nextProps.defaultActivedKey
            });
        }
    },
    _handleClick: function _handleClick(item) {
        var _props = this.props,
            onClick = _props.onClick,
            rowKey = _props.rowKey;
        var activeKey = this.state.activeKey;

        var hasSelected = activeKey === item.value ? true : false;
        if (!item.disabled) {
            if (hasSelected) {
                this.setState({ activeKey: '' });
            } else {
                this.setState({ activeKey: item.value });
            }
            if (onClick) {
                onClick(item, !hasSelected, rowKey);
            }
        }
    },
    _handleDPChange: function _handleDPChange(item, date, dateString) {
        var _props2 = this.props,
            onClick = _props2.onClick,
            rowKey = _props2.rowKey;

        if (onClick) {
            onClick({ text: dateString, value: date, type: item.type, compare: item.compare }, true, rowKey);
        }
    },
    _handleRPChange: function _handleRPChange(item, date, dateString) {
        var _props3 = this.props,
            onClick = _props3.onClick,
            rowKey = _props3.rowKey;

        if (onClick) {
            onClick({ text: dateString, value: date, type: 'date', compare: item.compare }, true, rowKey);
        }
    },
    _handleINChange: function _handleINChange(value) {
        this.state.INValue = value;
    },
    _handleINBlur: function _handleINBlur(item) {
        var _props4 = this.props,
            onClick = _props4.onClick,
            rowKey = _props4.rowKey;
        var INValue = this.state.INValue;

        if (onClick && INValue.length === 2) {
            onClick({ text: INValue.join('-'), value: INValue, type: item.type, compare: item.compare }, true, rowKey);
        }
    },
    _getItemsData: function _getItemsData(items) {
        var _props5 = this.props,
            showAll = _props5.showAll,
            minCount = _props5.minCount;

        return !showAll && items.length > minCount ? _.slice(items, 0, minCount) : items;
    },
    _renderContent: function _renderContent() {
        var _this = this;
        var _props6 = this.props,
            items = _props6.items,
            colSpan = _props6.colSpan;
        var activeKey = this.state.activeKey;


        return _.map(this._getItemsData(items), function (item, index) {
            var cls = classnames({
                'yyui-filter-item': true,
                'disabled': item.disabled,
                'actived': activeKey === item.value
            });
            if (item.type === 'input') {
                return React.createElement(
                    YYCol,
                    { span: colSpan },
                    React.createElement(
                        'span',
                        {
                            className: cls,
                            value: item.value,
                            onClick: _this._handleClick.bind(_this, item),
                            title: item.text
                        },
                        item.text
                    )
                );
            } else if (item.type === 'number') {
                return React.createElement(
                    YYCol,
                    { span: colSpan },
                    React.createElement(YYInputNumber, {
                        className: cls + ' yyui-filter-inputnumber',
                        defaultValue: [],
                        range: true,
                        size: 'small',
                        onChange: _this._handleINChange.bind(_this),
                        onBlur: _this._handleINBlur.bind(_this, item)
                    })
                );
            } else if (item.type === 'date') {
                return React.createElement(
                    YYCol,
                    { span: colSpan },
                    React.createElement(YYDatePicker, {
                        className: cls + ' yyui-filter-datepicker',
                        size: 'small',
                        onChange: _this._handleDPChange.bind(_this, item)
                    })
                );
            } else if (item.type === 'range') {
                return React.createElement(
                    YYCol,
                    { span: colSpan },
                    React.createElement(YYRangePicker, {
                        className: cls + ' yyui-filter-rangepicker',
                        size: 'small',
                        onChange: _this._handleRPChange.bind(_this, item)
                    })
                );
            }
        });
    },
    render: function render() {
        //判断是否展开，并显示滚动条样式
        var rowCls = classnames({
            'expand': this.props.showAll,
            'yyui-filter-single': true
        });
        return React.createElement(
            YYRow,
            { className: rowCls },
            this._renderContent()
        );
    }
});

module.exports = CPFilterSingle;