'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames2 = require('classnames');

var _classnames3 = _interopRequireDefault(_classnames2);

var _yylibUi = require('yylib-ui');

var _SearchCondition = require('./SearchCondition');

var _SearchCondition2 = _interopRequireDefault(_SearchCondition);

var _SearchScheme = require('./SearchScheme');

var _SearchScheme2 = _interopRequireDefault(_SearchScheme);

var _SearchTable = require('./SearchTable');

var _SearchTable2 = _interopRequireDefault(_SearchTable);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var field = _yylibUi.YYClass.field,
    PropTypes = _yylibUi.YYClass.PropTypes;
var Header = _yylibUi.YYLayout.Header,
    Sider = _yylibUi.YYLayout.Sider,
    Content = _yylibUi.YYLayout.Content,
    Footer = _yylibUi.YYLayout.Footer;


var FormItemType = require('../../../widgets/FormItemType');

function noop() {}

var uiMeta = {
    name: 'ijz-search',
    fields: [
    //field 参数列表：字段属性名|属性默认值|属性类型|是否必填|属性描述
    field('prefixCls', 'ijz-search', PropTypes.string, false, '样式名前缀'), field('className', '', PropTypes.string, false, '样式'), field('visible', true, PropTypes.bool, false, '组件是否显示'), field('onSearchClick', noop, PropTypes.func, false, '查询回调')]
};

var IjzSearch = _yylibUi.YYClass.create({
    uiMeta: uiMeta,

    displayName: 'IjzSearch',

    getInitialState: function getInitialState() {
        return {
            _dataSource: [],
            _dataItem: []
        };
    },
    componentWillMount: function componentWillMount() {
        this.procDataItem();
    },
    componentWillReceiveProps: function componentWillReceiveProps() {
        this.procDataItem();
    },
    getClassName: function getClassName() {
        var prefixCls = this.props.prefixCls;

        return (0, _classnames3.default)(prefixCls);
    },
    procDataItem: function procDataItem() {
        var children = this.props.children;
        var _state = this.state,
            _dataItem = _state._dataItem,
            _dataSource = _state._dataSource;

        _react2.default.Children.map(children, function (item) {
            if (_react2.default.isValidElement(item)) {
                var inputprops = item.props.inputprops ? _lodash2.default.clone(item.props.inputprops) : undefined;
                // 下拉选择特殊处理
                if (inputprops && item.props.inputtype === FormItemType.select) {
                    var items = item.props.children ? _lodash2.default.clone(item.props.children) : [];
                    var options = [];
                    if (items && items.length > 0) {
                        _lodash2.default.forEach(items, function (item) {
                            var option = {};
                            option.value = item.value;
                            option.text = item.text || item.children;
                            options.push(option);
                        });
                    }
                    inputprops.items = options;
                }
                _dataItem.push({
                    key: item.props.uikey,
                    fieldkey: item.props.fieldkey || item.props.uikey,
                    title: item.props.title,
                    fieldtype: item.props.fieldtype,
                    inputtype: item.props.inputtype,
                    inputprops: inputprops,
                    oper: item.props.oper || [],
                    enableOrder: item.props.enableOrder === undefined ? false : item.props.enableOrder,
                    enableSearch: item.props.enableSearch === undefined ? true : item.props.enableSearch,
                    hidden: item.props.hidden === undefined ? false : item.props.hidden,
                    required: item.props.required === undefined ? false : item.props.required,
                    readonly: item.props.readonly === undefined ? false : item.props.readonly,
                    presetFunc: item.props.funcId ? {
                        funcId: item.props.funcId,
                        funcCode: item.props.funcCode,
                        funcName: item.props.funcName
                    } : null
                });
                if (item.props.required && _lodash2.default.findIndex(_dataSource, { key: item.props.uikey }) === -1) {
                    _dataSource.push(_extends({}, _dataItem[_dataItem.length - 1], { id: Date.now() }));
                }
            }
        });
    },
    handleConditionClick: function handleConditionClick(key) {
        var _state2 = this.state,
            _dataItem = _state2._dataItem,
            _dataSource = _state2._dataSource;

        var cond = _lodash2.default.find(_dataItem, { key: key });
        if (_lodash2.default.findIndex(_dataSource, { key: key }) === -1) {
            _dataSource.push(_extends({}, cond, { id: Date.now() }));
            this.setState({ _dataSource: _dataSource });
        }
    },
    handleSearchClick: function handleSearchClick() {
        var onSearchClick = this.props.onSearchClick;
        var _dataSource = this.state._dataSource;

        var cb = _dataSource.map(function (_ref) {
            var key = _ref.key,
                logic = _ref.logic,
                value = _ref.value;

            return { key: key, logic: logic, value: value };
        });
        onSearchClick(cb);
    },
    handleClearClick: function handleClearClick() {
        this.setState({ _dataSource: [] });
    },
    handleSaveScheme: function handleSaveScheme() {},
    render: function render() {
        var _props = this.props,
            className = _props.className,
            visible = _props.visible,
            otherProps = _objectWithoutProperties(_props, ['className', 'visible']);

        var _state3 = this.state,
            _dataItem = _state3._dataItem,
            _dataSource = _state3._dataSource;


        var visibleClass = (0, _classnames3.default)(_defineProperty({}, this.getClassName() + '-hide', !visible));

        return _react2.default.createElement(
            _yylibUi.YYLayout,
            { className: (0, _classnames3.default)(this.getClassName(), visibleClass, className) },
            _react2.default.createElement(
                _yylibUi.YYLayout,
                null,
                _react2.default.createElement(
                    Sider,
                    null,
                    _react2.default.createElement(
                        _yylibUi.YYTabs,
                        { defaultActiveKey: '1' },
                        _react2.default.createElement(
                            _yylibUi.YYTab,
                            { tab: '\u5019\u9009\u6761\u4EF6', key: '1' },
                            _react2.default.createElement(_SearchCondition2.default, { dataItem: _dataItem, onConditionClick: this.handleConditionClick })
                        ),
                        _react2.default.createElement(
                            _yylibUi.YYTab,
                            { tab: '\u67E5\u8BE2\u65B9\u6848', key: '2' },
                            _react2.default.createElement(_SearchScheme2.default, null)
                        )
                    )
                ),
                _react2.default.createElement(
                    Content,
                    null,
                    _react2.default.createElement(
                        _yylibUi.YYTabs,
                        { defaultActiveKey: '1', type: 'card' },
                        _react2.default.createElement(
                            _yylibUi.YYTab,
                            { tab: '\u67E5\u8BE2\u6761\u4EF6', key: '1' },
                            _react2.default.createElement(_SearchTable2.default, { dataSource: _dataSource })
                        )
                    )
                )
            ),
            _react2.default.createElement(
                Footer,
                null,
                _react2.default.createElement(
                    _yylibUi.YYButton,
                    { type: 'error', onClick: this.handleSaveScheme },
                    '\u4FDD\u5B58\u65B9\u6848'
                ),
                _react2.default.createElement(
                    _yylibUi.YYButton,
                    { type: 'primary', onClick: this.handleSearchClick },
                    '\u67E5\u8BE2'
                ),
                _react2.default.createElement(
                    _yylibUi.YYButton,
                    { onClick: this.handleClearClick },
                    '\u6E05\u7A7A'
                )
            )
        );
    }
});

module.exports = IjzSearch;