'use strict';

/**
** 参照中抽取的内部公共组件：dialog底部区域
**/
var React = require('react');
var _ = require('lodash');
var YYClass = require('../../base/YYClass');
var YYTag = require('../../tag/YYTag');
var YYButton = require('../../button/YYButton');
var YYScrollbar = require('../../scrollbar/YYScrollbar');
var YYRadio = require('../../formcontrols/radio/YYRadio');
var YYRadioGroup = require('../../formcontrols/radio/YYRadioGroup');

var _require = require('../constants/ReferConstants'),
    REFER_TAGFIELD = _require.REFER_TAGFIELD;

var AuthToken = require("../../../utils/AuthToken");
var PropTypes = YYClass.PropTypes;
var field = YYClass.field;
var store = window.localStorage;
var storeKey = null;

//定义META
var uiMeta = {
	name: 'refer-footer',
	fields: [
	//field参数列表：字段属性名|属性默认值|属性类型|是否必填|属性描述
	field('refinfokey', null, PropTypes.string, true, '参照key'), field('refname', null, PropTypes.string, true, '当前参照名称'), field('idField', null, PropTypes.string, true, 'id字段'), field('nameField', null, PropTypes.string, true, 'name字段'), field('codeField', null, PropTypes.string, true, 'code字段'), field('selectedDatas', null, PropTypes.array, true, '选择的数据行'), field('multiselect', null, PropTypes.bool, false, '是否支持多选'), field('customButtons', null, PropTypes.oneOfType([PropTypes.element, PropTypes.arrayOf(PropTypes.element)]), false, '自定义按钮'), field('onOk', null, PropTypes.func, false, '确认操作回调函数'), field('onCancel', null, PropTypes.func, true, '取消操作回调函数'), field('onClean', null, PropTypes.func, true, '清除操作回调函数'), field('onRefresh', null, PropTypes.func, true, '刷新操作回调函数'), field('onTagClose', null, PropTypes.func, true, '单个已选项被移除的操作回调函数')]
};
var FooterView = YYClass.create({
	uiMeta: uiMeta,
	getInitialState: function getInitialState() {
		return {
			tagField: this._getTagField()

		};
	},

	_getTagField: function _getTagField() {
		var tagField = this.props.nameField;
		var refinfokey = this.props.refinfokey;

		if (store) {
			var userCode = AuthToken.getUserCode();
			storeKey = REFER_TAGFIELD + userCode + "-" + refinfokey;
			if (store[storeKey]) {
				tagField = JSON.parse(store[storeKey]);
			}
		}
		return tagField;
	},
	componentWillUnmount: function componentWillUnmount() {
		var tagField = this.state.tagField;
		store.setItem(storeKey, JSON.stringify(tagField));
	},
	_getTags: function _getTags() {
		var _this = this;

		var _props = this.props,
		    nameField = _props.nameField,
		    idField = _props.idField,
		    selectedDatas = _props.selectedDatas;

		var tagField = this.state.tagField;
		var selectedTags = null;
		if (selectedDatas && nameField) {
			selectedTags = [];
			_.forEach(selectedDatas, function (selectedData, index) {
				if (selectedData && selectedData[idField]) {
					var id = selectedData[idField];
					selectedTags.push(React.createElement(
						YYTag,
						{ closable: true, afterClose: function afterClose() {
								return _this.props.onTagClose(id);
							}, key: id },
						selectedData[tagField]
					));
				}
			});
		};

		return selectedTags;
	},

	// 切换显示name或者code
	onChange: function onChange(e) {
		this.setState({
			tagField: e.target.value
		});
	},
	render: function render() {
		var that = this;
		var refname = this.props.refname;
		if (this.props.multiselect) {
			var selectedTags = this._getTags();
			var hasTags = false;
			if (selectedTags && selectedTags.length > 0) {
				hasTags = true;
			}
			var nameField = this.props.nameField;
			var codeField = this.props.codeField;
			return React.createElement(
				'div',
				{ className: 'yyui-refer-footer' },
				React.createElement(
					'div',
					null,
					React.createElement(
						'span',
						{ className: 'yyui-refer-selected-label' },
						'\u5DF2\u9009\u62E9',
						refname,
						'\uFF1A'
					),
					hasTags ? React.createElement(
						YYRadioGroup,
						{ style: { display: 'inline-block' }, defaultValue: nameField, onChange: this.onChange, value: that.state.tagField },
						React.createElement(
							YYRadio,
							{ key: 'name', value: nameField },
							'\u540D\u79F0'
						),
						React.createElement(
							YYRadio,
							{ key: 'code', value: codeField },
							'\u7F16\u7801'
						)
					) : null
				),
				React.createElement(
					YYScrollbar,
					{ style: { height: 55 } },
					selectedTags
				),
				React.createElement(
					'div',
					{ className: 'yyui-refer-buttons', style: { textAlign: 'right', paddingTop: 10 } },
					that.props.customButtons,
					React.createElement(
						YYButton,
						{ ghost: true, onClick: that.props.onRefresh },
						'\u5237\u65B0'
					),
					React.createElement(
						YYButton,
						{ ghost: true, onClick: that.props.onClean },
						'\u6E05\u9664'
					),
					React.createElement(
						YYButton,
						{ ghost: true, type: 'primary', onClick: that.props.onCancel },
						'\u53D6\u6D88'
					),
					React.createElement(
						YYButton,
						{ onClick: that.props.onOk, type: 'primary' },
						'\u786E\u8BA4'
					)
				)
			);
		} else {
			return React.createElement(
				'div',
				{ className: 'yyui-refer-footer' },
				React.createElement(
					'div',
					{ className: 'yyui-refer-buttons' },
					that.props.customButtons,
					React.createElement(
						YYButton,
						{ ghost: true, onClick: that.props.onRefresh },
						'\u5237\u65B0'
					),
					React.createElement(
						YYButton,
						{ ghost: true, onClick: that.props.onClean },
						'\u6E05\u9664'
					),
					React.createElement(
						YYButton,
						{ ghost: true, type: 'primary', onClick: that.props.onCancel },
						'\u53D6\u6D88'
					),
					React.createElement(
						YYButton,
						{ onClick: that.props.onOk, type: 'primary' },
						'\u786E\u8BA4'
					)
				)
			);
		}
	}
});

module.exports = FooterView;